import bpy
import os
from bpy.types import Operator
from bpy import context
import addon_utils
from pathlib import Path

###################################################################################
# UI SWITCH BUTON
###################################################################################
class RAIN_OP_switchinput(bpy.types.Operator):
    bl_idname = "switch.buttonrain"
    bl_label = "switch.buttonrain"

    index: bpy.props.StringProperty(name="None")
    def execute(self, context):

        obj = context.object
        modifier = obj.modifiers["Baga_Rain_Generator"]
        blender_version = bpy.app.version
        minimum_version = (3, 5, 0)
        if blender_version >= minimum_version:
            if modifier[self.index] == True:
                modifier[self.index] = False
            else:
                modifier[self.index] = True
        else:
            if modifier[self.index] == 1:
                modifier[self.index] = 0
            else:
                modifier[self.index] = 1
        bpy.ops.object.editmode_toggle()
        bpy.ops.object.editmode_toggle()

        return {'FINISHED'}

        
###################################################################################
# ADD TARGET
###################################################################################
class RAIN_ADD_Target(Operator):
    """Adds the selected object as a target for the rain. Select your object then the rain."""
    bl_idname = "rainadd.target"
    bl_label = "Add Target"
    bl_options = {'REGISTER', 'UNDO'}

    index: bpy.props.IntProperty(name="Input Index", default=0)

    @classmethod
    def poll(cls, context):
        return (bpy.context.object.mode == 'OBJECT')

    def execute(self, context):
        
        target = bpy.context.active_object
        modifier = target.modifiers["Baga_Rain_Generator"]
        collection = modifier["Input_"+str(self.index)]

        targets = bpy.context.selected_objects
        if target in targets:
            targets.remove(target)

        if len(targets) < 1:
            Warning(message = "First select a target you want to add. Then add rain to selection before using : + Add Target.", title = "Wrong selection", icon = 'INFO')
            return {'FINISHED'}

        for obj in targets:
            if obj.name not in collection.objects:
                collection.objects.link(obj)
        
        return {'FINISHED'}


###################################################################################
# REMOVE TARGET
###################################################################################
class RAIN_REMOVE_Target(Operator):
    """Remove the selected object from the target collection. Select your object then the rain."""
    bl_idname = "rainremove.target"
    bl_label = "Remove Target"
    bl_options = {'REGISTER', 'UNDO'}

    index: bpy.props.IntProperty(name="Input Index", default=0)

    @classmethod
    def poll(cls, context):
        return (bpy.context.object.mode == 'OBJECT')

    def execute(self, context):
        
        target = bpy.context.active_object
        rain_modifier = target.modifiers["Baga_Rain_Generator"]
        collection = rain_modifier["Input_"+str(self.index)]
        targets = bpy.context.selected_objects
        if target in targets:
            targets.remove(target)

        if len(targets) < 1:
            Warning(message = "First select assets you want to remove. Then add ivy to selection before using : + Remove Assets.", title = "Wrong selection", icon = 'INFO')
            return {'FINISHED'}

        for obj in targets:
            if obj.name in collection.objects:
                collection.objects.unlink(obj)
        
        return {'FINISHED'}
    
    
###################################################################################
# DISPLAY WARNING
###################################################################################
def Warning(message = "", title = "Message Box", icon = 'INFO'):

    def draw(self, context):
        self.layout.label(text=message)
    bpy.context.window_manager.popup_menu(draw, title = title, icon = icon)
